==> mythdvd_0.16.orig.tar.gz: mythdvd-0.16/i18n/mythdvd_ca.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>La seva connexió amb el procés de trascodificació s&apos;ha perdut. Això no és bó.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>No puc connectar amb el procés de Trascodificació. Provi de prèmer qualsevol tecla numèrica per iniciar-lo. Si després encara llegeix aquest missatge, alguna cosa va malament.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Intentant connectar amb el procés de trascodificació no s&apos;ha trovat el nom de màquina, això és un error fatal.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Error de comunicacions (socket). Aquest és un error fatal.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Alguna cosa no va bé, pero no sé quina.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Tasca %1 de %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>No hi han tasques ni res més a fer. Pot prèmer 0 per volcar un DVD.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>No hi ha tasques. Esperant/comprovant si hi ha un nou DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>No hi han tasques pendents ni res més a fer. Pot prèmer 0 si vol volcar un disc.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Cancelant...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Nou volcat</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Cancel·lar tasca</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

No hi ha cap comanda definida per als VCD.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>D&apos;acord, aniré a la configuració</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

No hi ha cap dispositiu VCD definit.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

No hi ha una comanda assignada per a la reproducció de DVD.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

No hi ha un dispositiu de DVD definit.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Localització del dispositiu VCD</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Aquest dispositiu ha d&apos;existir, i l&apos;usuari de MythDVD hi ha de tenir permís de lectura.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Localització del dispositiu DVD</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuració General</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Comanda per a la reproducció de DVD</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Pot especificar qualsevol comanda per a reproduir DVDs (p.ex.: mplayer, ogle, xine...). Si s&apos;especifica, %d es substituirà per el dispositiu de DVD (p.ex.: /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Comanda per a la reproducció de VCD</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Pot especificar qualsevol comanda per a reproduir VCDs (p.ex.: mplayer, xine...). Si s&apos;especifica, %d es substituirà per el dispositiu de VCD (p.ex.: /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Configuració del reproductor de DVD</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Configuració del reproductor de VCD</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Directori per emmagetzemar arxius temporals</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Aquest directori ha d&apos;existir i l&apos;usuari que executa MythDVD hi ha de tenir permís en escriptura.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Comanda de reproducció del títol</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Aquesta és una comanda per a la previsualització de un títol del DVD. Si s&apos;especifica %t serà substituit pel títol, %d pel dispositiu, %a per la pista d&apos;àudio, %c per als canals d&apos;àudio.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Paràmetres dels subtítols:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Si escull subtítols en el volcat, aquesta comanda s&apos;afegirà al final de la comanda del reproducció del titol per permetre la previsualitzacioó dels subtítols. Si s&apos;especifica %s es substituirà per la pista de subtítols.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Comanda de trascodificació bàsica</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>Aquesta es la comanda (sense paràmetres) bàsica per a la trasc odificació en el seu sistema.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>Número de port del MTD</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>El número de port que es farà servir per a la comunicació amb el MTD (Myth Transcoding Daemon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Traçes del MTD a la finestra del terminal</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Si s&apos;activa, el MTD (Myth Transcoding Daemon) donarà traces a la finestra des d&apos;on s&apos;ha iniciat, en cas contrari, ho escriurà en un arxiu anomenat mtd.log que es trovarà en el nivell superior del directori de volcat.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Trascodificar àudio AC3</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Si s&apos;activa, el MTD (Myth Transcoding Daemon), per omisió, conservarà el sò AC3 (Dolby Digital) en la trascodificació.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Fer servid &apos;xvid&apos; en lloc de &apos;divx&apos;</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Si s&apos;activa, MythDVD intentarà fer servir el còdec &apos;xvid&apos; (obert, lliure) avans que el &apos;divx&apos; si és que pot fer-ho.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Nivell de prioritat (nice) del MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Determina la prioritat del NTD (Myth Transcoder Daemon). Un valor superior significa menys prioritat (més processador per a altres tasques).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Segments de vídeo volcats</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Si s&apos;especifica quelcom diferent de 0, els segments de vídeo seran volcats en fragments d&apos;aquest tamany (en MB). Aplica a tant als arxius temporals com als definitius.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>Configuració del volcador de DVD</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>Configuració del MTD</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Esperant a accedir al DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Volcant al arxiu ~ </translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Volcat perfecte de DVD de %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Trascodificació de %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Esperant autorització per a iniciar trascodificació</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Trascodificant, passada 1 de 2 ~ </translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Trascodificant, passada 2 de 2 ~ </translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Trascodificant ~ </translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Es trascodificador està pensant</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Tasques simultànies de trascodificació</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Determina el nombre de tasques de trascodificació simultànies. Si es posa a 1 (el valor per omisió) només hi haurà una tasca.</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Volcar/Trascodificar</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Tasca 1 de 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Duració:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Sel·leccionat:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualitat:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Pista d&apos;àudio:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>Àudio AC3:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Subtítols:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Veure:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Títol 1 de 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Títol %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfecte</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Títol %1 de %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Processar el títol escollit</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Processar els títols escollits</translation>
    </message>
</context>
</TS>

==> mythdvd_0.17.orig.tar.gz: mythdvd-0.17/i18n/mythdvd_ca.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>La seva connexió amb el procés de trascodificació s&apos;ha perdut. Això no és bó.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>No puc connectar amb el procés de Trascodificació. Provi de prèmer qualsevol tecla numèrica per iniciar-lo. Si després encara llegeix aquest missatge, alguna cosa va malament.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Intentant connectar amb el procés de trascodificació no s&apos;ha trovat el nom de màquina, això és un error fatal.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Error de comunicacions (socket). Aquest és un error fatal.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Alguna cosa no va bé, pero no sé quina.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Tasca %1 de %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>No hi han tasques ni res més a fer. Pot prèmer 0 per volcar un DVD.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>No hi ha tasques. Esperant/comprovant si hi ha un nou DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>No hi han tasques pendents ni res més a fer. Pot prèmer 0 si vol volcar un disc.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Cancelant...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Nou volcat</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Cancel·lar tasca</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

No hi ha cap comanda definida per als VCD.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>D&apos;acord, aniré a la configuració</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

No hi ha cap dispositiu VCD definit.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

No hi ha una comanda assignada per a la reproducció de DVD.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

No hi ha un dispositiu de DVD definit.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Localització del dispositiu VCD</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Aquest dispositiu ha d&apos;existir, i l&apos;usuari de MythDVD hi ha de tenir permís de lectura.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Localització del dispositiu DVD</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuració General</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Comanda per a la reproducció de DVD</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Pot especificar qualsevol comanda per a reproduir DVDs (p.ex.: mplayer, ogle, xine...). Si s&apos;especifica, %d es substituirà per el dispositiu de DVD (p.ex.: /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Comanda per a la reproducció de VCD</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Pot especificar qualsevol comanda per a reproduir VCDs (p.ex.: mplayer, xine...). Si s&apos;especifica, %d es substituirà per el dispositiu de VCD (p.ex.: /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Configuració del reproductor de DVD</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Configuració del reproductor de VCD</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Directori per emmagetzemar arxius temporals</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Aquest directori ha d&apos;existir i l&apos;usuari que executa MythDVD hi ha de tenir permís en escriptura.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Comanda de reproducció del títol</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Aquesta és una comanda per a la previsualització de un títol del DVD. Si s&apos;especifica %t serà substituit pel títol, %d pel dispositiu, %a per la pista d&apos;àudio, %c per als canals d&apos;àudio.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Paràmetres dels subtítols:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Si escull subtítols en el volcat, aquesta comanda s&apos;afegirà al final de la comanda del reproducció del titol per permetre la previsualitzacioó dels subtítols. Si s&apos;especifica %s es substituirà per la pista de subtítols.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Comanda de trascodificació bàsica</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>Aquesta es la comanda (sense paràmetres) bàsica per a la trasc odificació en el seu sistema.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>Número de port del MTD</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>El número de port que es farà servir per a la comunicació amb el MTD (Myth Transcoding Daemon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Traçes del MTD a la finestra del terminal</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Si s&apos;activa, el MTD (Myth Transcoding Daemon) donarà traces a la finestra des d&apos;on s&apos;ha iniciat, en cas contrari, ho escriurà en un arxiu anomenat mtd.log que es trovarà en el nivell superior del directori de volcat.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Trascodificar àudio AC3</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Si s&apos;activa, el MTD (Myth Transcoding Daemon), per omisió, conservarà el sò AC3 (Dolby Digital) en la trascodificació.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Fer servid &apos;xvid&apos; en lloc de &apos;divx&apos;</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Si s&apos;activa, MythDVD intentarà fer servir el còdec &apos;xvid&apos; (obert, lliure) avans que el &apos;divx&apos; si és que pot fer-ho.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Nivell de prioritat (nice) del MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Determina la prioritat del NTD (Myth Transcoder Daemon). Un valor superior significa menys prioritat (més processador per a altres tasques).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Segments de vídeo volcats</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Si s&apos;especifica quelcom diferent de 0, els segments de vídeo seran volcats en fragments d&apos;aquest tamany (en MB). Aplica a tant als arxius temporals com als definitius.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>Configuració del volcador de DVD</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>Configuració del MTD</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Esperant a accedir al DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Volcant al arxiu ~ </translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Volcat perfecte de DVD de %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Trascodificació de %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Esperant autorització per a iniciar trascodificació</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Trascodificant, passada 1 de 2 ~ </translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Trascodificant, passada 2 de 2 ~ </translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Trascodificant ~ </translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Es trascodificador està pensant</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Tasques simultànies de trascodificació</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Determina el nombre de tasques de trascodificació simultànies. Si es posa a 1 (el valor per omisió) només hi haurà una tasca.</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Volcar/Trascodificar</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Tasca 1 de 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Duració:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Sel·leccionat:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualitat:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Pista d&apos;àudio:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>Àudio AC3:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Subtítols:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Veure:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Títol 1 de 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Títol %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfecte</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Títol %1 de %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Processar el títol escollit</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Processar els títols escollits</translation>
    </message>
</context>
</TS>
